==> haskell-prettyprinter-compat-ansi-wl-pprint-1.0.2-232.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-compat-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-compat-ansi-wl-pprint
version:              1.0.2
visibility:           public
id:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-J09lbNJGa1YGlSNL6jHLne

key:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-J09lbNJGa1YGlSNL6jHLne

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Drop-in compatibility package to migrate from »ansi-wl-pprint« to »prettyprinter«.

description:          See README.md
category:             User Interfaces, Text
abi:                  b08898beb5902ef9ca10db9bfba66126
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-compat-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-compat-ansi-wl-pprint-1.0.2-J09lbNJGa1YGlSNL6jHLne

depends:
    base-4.18.2.1 prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo
    prettyprinter-ansi-terminal-1.1.3-LcajTeMLJmqJgHikO6kzwA text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html/prettyprinter-compat-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-compat-ansi-wl-pprint-1.0.2-236-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-compat-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-compat-ansi-wl-pprint
version:              1.0.2
visibility:           public
id:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-F7OtoluWLj7DbOIXyN1tRX

key:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-F7OtoluWLj7DbOIXyN1tRX

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Drop-in compatibility package to migrate from »ansi-wl-pprint« to »prettyprinter«.

description:          See README.md
category:             User Interfaces, Text
abi:                  185f2ba98d5b04714005bbe2b06690a4
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-compat-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-compat-ansi-wl-pprint-1.0.2-F7OtoluWLj7DbOIXyN1tRX

depends:
    base-4.18.2.1 prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    prettyprinter-ansi-terminal-1.1.3-8bIrDelGjXzHJngnsc4lAf text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html/prettyprinter-compat-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
